CArc

Struct CArc 

pub struct CArc<T, TAllocator: Allocator> { /* private fields */ }
A smart pointer that can be used to share ownership of a value.

This struct is equivalent to the standard Arc type, but is #[repr(C)] and thus safe to use across the ffi boundaries.

Implementations

Source

impl<T, TAllocator: Allocator> CArc<T, TAllocator>

pub fn new(value: T) -> Result<Self, CArcError>
where TAllocator: Default,

Creates a new CArc with the default allocator.

Errors

For details see CArcError.

pub fn with_allocator( value: T, allocator: TAllocator, ) -> Result<Self, CArcError>

Creates a new CArc with a custom allocator.

Errors

For details see CArcError.

pub fn strong_count(carc: &Self) -> u32

Returns the number of strong references to the CArc.

pub fn weak_count(carc: &Self) -> u32

Returns the number of weak references to the CArc.

pub const fn data(carc: &Self) -> &T

Returns a reference to the underlying value.

pub fn downgrade( carc: &Self, ) -> Result<CWeak<T, TAllocator>, MaxReferencesExceededError>

Creates a new CWeak reference to the CArc.

Errors

If the weak reference count is too high. Cannot exceed MAX_REFERENCES.

pub fn abandon(carc: Self) -> Option<AbandonResult<T, TAllocator>>

Abandons current CArc.

This function returns None if the underlying strong reference counter is still positive. Otherwise it returns the underlying data and a weak reference to the CArc. In particular the data will be dropped by the caller if that was the last strong reference.

pub const fn into_raw_ptr(carc: Self) -> *mut u8

Converts the CArc into a raw pointer.

Notes
  • This method does not touch internal reference counters, self is simply forgotten.
  • The caller must ensure that the pointer does not outlive the CArc.
pub const unsafe fn from_raw_ptr(ptr: *mut u8) -> Self

Converts a raw pointer back to a CArc.

Safety
  • The caller must ensure that the pointer came from the previous call to CArc::into_raw_ptr.
  • The caller must ensure that the raw pointer won’t be used after the call.

Otherwise the behavior is undefined.