pub struct CWeak<T, TAllocator: Allocator> { /* private fields */ }Expand description
A weak reference to the underlying CArc.
This object cannot inspect the underlying value (unless T is Copy).
But it does track weak references, and each weak reference can build
a strong reference, assuming any other strong reference is alive.
Implementations
Sourceimpl<T, TAllocator: Allocator> CWeak<T, TAllocator>
impl<T, TAllocator: Allocator> CWeak<T, TAllocator>
Sourcepub fn strong_count(&self) -> u32
pub fn strong_count(&self) -> u32
Returns the number of strong references to the CWeak.
Sourcepub fn weak_count(&self) -> u32
pub fn weak_count(&self) -> u32
Returns the number of weak references to the CWeak.
Sourcepub fn data(&self) -> &Twhere
T: Copy,
pub fn data(&self) -> &Twhere
T: Copy,
Returns a reference to the underlying data.
This function is only available if T implements Copy.
That is because being Copy means it is not Drop. And
so we don’t need strong references to keep the data alive.
Sourcepub fn upgrade(&self) -> Result<CArc<T, TAllocator>, WeakUpgradeError>
pub fn upgrade(&self) -> Result<CArc<T, TAllocator>, WeakUpgradeError>